GpuVm

Struct GpuVm 

pub struct GpuVm<T: DriverGpuVm> { /* private fields */ }
A DRM GPU VA manager.

This object is refcounted, but the locations of mapped ranges may only be accessed or changed via the special unique handle UniqueRefGpuVm.

Invariants

  • Stored in an allocation managed by the refcount in self.vm.
  • Access to data and the gpuvm interval tree is controlled via the UniqueRefGpuVm type.
  • Does not contain any sparse GpuVa<T> instances.

Implementations

Source

impl<T: DriverGpuVm> GpuVm<T>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> GpuVmProjection<'__pin, T>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • vm

These fields are not structurally pinned:

  • data
Source

impl<T: DriverGpuVm> GpuVm<T>

pub fn new<E, Ctx: DeviceContext>( name: &'static CStr, dev: &Device<T::Driver, Ctx>, r_obj: &T::Object, range: Range<u64>, reserve_range: Range<u64>, data: T, ) -> Result<UniqueRefGpuVm<T>, E>

Creates a GPUVM instance.

pub unsafe fn from_raw<'a>(ptr: *mut drm_gpuvm) -> &'a Self

Access this GpuVm from a raw pointer.

Safety

The pointer must reference the struct drm_gpuvm in a valid GpuVm<T> that remains valid for at least 'a.

pub fn as_raw(&self) -> *mut drm_gpuvm

Returns a raw pointer to the embedded struct drm_gpuvm.

pub fn va_start(&self) -> u64

The start of the VA space.

pub fn va_length(&self) -> u64

The length of the GPU’s virtual address space.

pub fn va_range(&self) -> Range<u64>

Returns the range of the GPU virtual address space.

pub fn obtain( &self, obj: &T::Object, data: impl PinInit<T::VmBoData>, ) -> Result<ARef<GpuVmBo<T>>, AllocError>

Get or create the GpuVmBo for this gem object.

pub fn deferred_cleanup(&self)

Clean up buffer objects that are no longer used.

pub fn is_extobj(&self, obj: &T::Object) -> bool

Check if this GEM object is an external object for this GPUVM.