pub struct OpRemap<'op, T: DriverGpuVm> { /* private fields */ }Expand description
Represents an sm_step_remap operation that has not yet been completed.
Implementations
Sourceimpl<'op, T: DriverGpuVm> OpRemap<'op, T>
impl<'op, T: DriverGpuVm> OpRemap<'op, T>
Sourcepub fn prev(&self) -> Option<&OpRemapMapData>
pub fn prev(&self) -> Option<&OpRemapMapData>
The preceding part of a split mapping.
Sourcepub fn next(&self) -> Option<&OpRemapMapData>
pub fn next(&self) -> Option<&OpRemapMapData>
The subsequent part of a split mapping.
Sourcepub fn keep(&self) -> bool
pub fn keep(&self) -> bool
Indicates whether the drm_gpuva being removed is physically contiguous with the original
mapping request.
Optionally, if keep is set, drivers may keep the actual page table mappings for this
drm_gpuva, adding the missing page table entries only and update the drm_gpuvm
accordingly.
Sourcepub fn va_to_unmap(&self) -> &GpuVa<T>
pub fn va_to_unmap(&self) -> &GpuVa<T>
The range being unmapped.
Sourcepub fn obj(&self) -> &T::Object
pub fn obj(&self) -> &T::Object
The drm_gem_object whose VA is being remapped.
Sourcepub fn remap(
self,
va_alloc: [GpuVaAlloc<T>; 2],
prev_data: impl PinInit<T::VaData>,
next_data: impl PinInit<T::VaData>,
) -> (OpRemapped<'op, T>, OpRemapRet<T>)
pub fn remap( self, va_alloc: [GpuVaAlloc<T>; 2], prev_data: impl PinInit<T::VaData>, next_data: impl PinInit<T::VaData>, ) -> (OpRemapped<'op, T>, OpRemapRet<T>)
Update the GPUVM to perform the remapping.