UniqueRefGpuVm

Struct UniqueRefGpuVm 

pub struct UniqueRefGpuVm<T: DriverGpuVm>(/* private fields */);
The core of the DRM GPU VA manager.

This object is a unique reference to the VM that can access the interval tree and the Rust data field.

Invariants

Each GpuVm instance has at most one UniqueRefGpuVm reference.

Implementations

Source

impl<T: DriverGpuVm> UniqueRefGpuVm<T>

pub fn sm_map(&mut self, req: OpMapRequest<'_, '_, T>) -> Result

Create a mapping, removing or remapping anything that overlaps.

Internally calls the DriverGpuVm callbacks similar to Self::sm_unmap, except that the DriverGpuVm::sm_step_map is called once to create the requested mapping.

pub fn sm_unmap( &mut self, addr: u64, length: u64, context: &mut T::SmContext<'_>, ) -> Result

Remove any mappings in the given region.

Internally calls DriverGpuVm::sm_step_unmap for ranges entirely contained within the given range, and DriverGpuVm::sm_step_remap for ranges that overlap with the range.

Source

impl<T: DriverGpuVm> UniqueRefGpuVm<T>

pub fn data_ref(&self) -> &T

Access the data owned by this UniqueRefGpuVm immutably.

pub fn data(&mut self) -> &mut T

Access the data owned by this UniqueRefGpuVm mutably.

Methods from Deref<Target = GpuVm<T>>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> GpuVmProjection<'__pin, T>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • vm

These fields are not structurally pinned:

  • data
pub fn as_raw(&self) -> *mut drm_gpuvm

Returns a raw pointer to the embedded struct drm_gpuvm.

pub fn va_start(&self) -> u64

The start of the VA space.

pub fn va_length(&self) -> u64

The length of the GPU’s virtual address space.

pub fn va_range(&self) -> Range<u64>

Returns the range of the GPU virtual address space.

pub fn obtain( &self, obj: &T::Object, data: impl PinInit<T::VmBoData>, ) -> Result<ARef<GpuVmBo<T>>, AllocError>

Get or create the GpuVmBo for this gem object.

pub fn deferred_cleanup(&self)

Clean up buffer objects that are no longer used.

pub fn is_extobj(&self, obj: &T::Object) -> bool

Check if this GEM object is an external object for this GPUVM.