pub struct OpRemapRet<T: DriverGpuVm> {
pub unmapped_va: GpuVaRemoved<T>,
pub unused_va: Option<GpuVaAlloc<T>>,
}Expand description
Struct containing objects removed or not used by OpRemap::remap.
Fields
unmapped_va: GpuVaRemoved<T>The drm_gpuva that was removed.
unused_va: Option<GpuVaAlloc<T>>If the remap did not split the region into two pieces, then the unused drm_gpuva is
returned here.